bl_info = {
    "name": "GP Render",
    "description": "Organise export of gp layers through compositor output",
    "author": "Samuel Bernou",
    "version": (0, 6, 1),
    "blender": (2, 93, 0),
    "location": "View3D",
    "warning": "",
    "doc_url": "", 
    "category": "Object" }


from . import OP_add_layer
from . import OP_merge_layers
from . import OP_clear
from . import OP_clean
from . import OP_connect_toggle
from . import OP_manage_outputs
from . import OP_scene_switch
from . import OP_crop_to_object
from . import OP_render_scenes
# from . import OP_check_layer_status
from . import OP_render_pdf
from . import prefs
from . import OP_setup_layers
from . import ui

from .fn import scene_aa

def update_scene_aa(context, scene):
    scene_aa(toggle=bpy.context.scene.use_aa)    

import bpy

def register():
    if bpy.app.background:
        return

    prefs.register()
    OP_add_layer.register()
    OP_clear.register()
    OP_clean.register()
    OP_connect_toggle.register()
    OP_merge_layers.register()
    OP_manage_outputs.register()
    OP_scene_switch.register()
    OP_crop_to_object.register()
    OP_render_scenes.register()
    # OP_check_layer_status.register()
    OP_render_pdf.register()
    OP_setup_layers.register()
    ui.register()
    # bpy.types.Scene.pgroup_name = bpy.props.PointerProperty(type = PROJ_PGT_settings)
    bpy.types.Scene.use_aa = bpy.props.BoolProperty(
        name='Use Native Anti Aliasing', 
        default=True, 
        description='\
Should be Off only if tree contains a merge_NG or alpha-over-combined renderlayers.\n\
Auto-set to Off when using node merge button\n\
Toggle: AA settings of and muting AA nested-nodegroup', 
        update=update_scene_aa)

def unregister():
    if bpy.app.background:
        return

    ui.unregister()
    OP_setup_layers.unregister()
    # OP_check_layer_status.unregister()
    OP_render_pdf.unregister()
    OP_render_scenes.unregister()
    OP_crop_to_object.unregister()
    OP_scene_switch.unregister()
    OP_manage_outputs.unregister()
    OP_merge_layers.unregister()
    OP_connect_toggle.unregister()
    OP_clean.unregister()
    OP_clear.unregister()
    OP_add_layer.unregister()
    prefs.unregister()

    del bpy.types.Scene.use_aa

if __name__ == "__main__":
    register()